@@ -3,7 +3,7 @@ package Sah::Schema::currency::code;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Currency'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use Locale::Codes::Currency_Codes ();
 
@@ -23,7 +23,7 @@ _
     'x.perl.coerce_rules' => ['From_str::to_upper'],
     examples => [
         {value=>'', valid=>0},
-        {value=>'idr', valid=>1, res=>'IDR'},
+        {value=>'idr', valid=>1, validated_value=>'IDR'},
         {value=>'foo', valid=>0},
     ],
 }, {}];
@@ -43,7 +43,7 @@ Sah::Schema::currency::code - Currency code
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::currency::code (from Perl distribution Sah-Schemas-Currency), released on 2020-03-04.
+This document describes version 0.007 of Sah::Schema::currency::code (from Perl distribution Sah-Schemas-Currency), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -81,7 +81,7 @@ Sample data:
 
  undef  # INVALID
 
- undef  # valid, becomes "IDR"
+ undef  # valid
 
  undef  # INVALID
 
