@@ -3,7 +3,7 @@ package Sah::Schema::currency::pair;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Currency'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [str => {
     summary => 'Fiat currency pair, e.g. USD/IDR',
@@ -24,7 +24,7 @@ _
     examples => [
         {value=>'', valid=>0},
         {value=>'idr', valid=>0},
-        {value=>'usd/idr', valid=>1, res=>'USD/IDR'},
+        {value=>'usd/idr', valid=>1, validated_value=>'USD/IDR'},
         {value=>'usd idr', valid=>0},
         {value=>'usd/foo', valid=>0},
     ],
@@ -45,7 +45,7 @@ Sah::Schema::currency::pair - Fiat currency pair, e.g. USD/IDR
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::currency::pair (from Perl distribution Sah-Schemas-Currency), released on 2020-03-04.
+This document describes version 0.007 of Sah::Schema::currency::pair (from Perl distribution Sah-Schemas-Currency), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -85,7 +85,7 @@ Sample data:
 
  undef  # INVALID
 
- undef  # valid, becomes "USD/IDR"
+ undef  # valid
 
  undef  # INVALID
 
